psychopy_ext.fmri.Analysis.ds2evds — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.Analysis.ds2evds

`Analysis.` `ds2evds`(ds, dur=2)

  Converts a dataset to an event-related dataset.

  Args: | ds
  Kwargs: | offset (int, default: 2) How much labels should be shifted due to the hemodynamic lag. A good practice is to first plot data to see where the peaks are. Default is 2 as a typical TR is between 2 and 3 secs and the lag is around 6 seconds. dur (int, default: 2) How many timepoints per condition. You may want to use a couple because the peak response may occupy more than a single timepoint (thus the default is 2).